pub fn place_order<T: Config>(para_id: TaskId, max_amount: BalanceOf<T>)Expand description
Place an on-demand Coretime order for para_id.
The caller is charged the current estimated spot price, which must not exceed
max_amount. The order is forwarded to the Relay chain at the end of the block.
origin: Must be a signed account with enough funds to pay the spot price.para_id: The parachain to schedule.max_amount: The maximum spot price the caller is willing to pay.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::place_order.